JsDoc Reference - ColVis

Generated by JsDoc Toolkit 2.4.0 on Wed Dec 15 2010 21:56:21 GMT-0000 (GMT)
HTML template: Codeview

# Class ColVis

ColVis
Defined in: ColVis.js.

Class Summary
Constructor Attributes | Constructor Name and Description
--- | ---
| ColVis(DataTables) ColVis provides column visiblity control for DataTables

Field Summary
Field Attributes | Field Name and Description
--- | ---
<static> | ColVis.aInstances Collection of all ColVis instances
<constant> | CLASS Name of this class
<static> <constant> | ColVis.VERSION ColVis version

Method Summary
Method Attributes | Method Name and Description
--- | ---
<static> | ColVis.fnRebuild(object) Rebuild the collection for a given table, or all tables if no parameter given
| fnRebuild() Rebuild the list of buttons for this instance (i.e.

Class Detail
ColVis(DataTables)
ColVis provides column visiblity control for DataTables

Parameters:
{object} DataTables
  settings object

Field Detail
<static> {Array} ColVis.aInstances
Collection of all ColVis instances

Default Value:
  []

<constant> {String} CLASS
Name of this class

Default Value:
  ColVis

<static> <constant> {String} ColVis.VERSION
ColVis version

Default Value:
  1.0.3

Method Detail
<static> ColVis.fnRebuild(object)
Rebuild the collection for a given table, or all tables if no parameter given

Parameters:
object
  oTable DataTable instance to consider - optional

Returns:
  void

fnRebuild()
Rebuild the list of buttons for this instance (i.e. if there is a column header update)

Returns:
  void